@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.21 1999/11/15 12:30:42 bazsi Exp $
+ * $Id: affile.c,v 1.22 1999/11/16 17:30:05 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -259,27 +259,21 @@ void expand_macro(int id, char **fmt, char **args[], struct log_info *msg)
 	case 'h': {
 		UINT8 *p1 = memchr(msg->host->data, '@', msg->host->length);
 		UINT8 *p2;
-
-		if (p1) {
-			int remaining;
-
-			p1++;
-			remaining = msg->host->length - (p1 - msg->host->data);
-			p2 = memchr(p1, '/', remaining);
-			ADD_MACRO_FMT("%s");
-			if (p2) 
-				ADD_MACRO_ARG(p2 - p1);
-			else
-				ADD_MACRO_ARG(remaining);
-			ADD_MACRO_ARG(p1);
+		int remaining;
+		
+		if (p1) 
+			p1++; 
+		else 
+			p1 = msg->host->data;
+		remaining = msg->host->length - (p1 - msg->host->data);
+		p2 = memchr(p1, '/', remaining);
+		ADD_MACRO_FMT("%s");
+		if (p2) 
+			ADD_MACRO_ARG(p2 - p1);
+		else
+			ADD_MACRO_ARG(remaining);
+		ADD_MACRO_ARG(p1);
 							
-		}
-		else {
-			ADD_MACRO_FMT("%S");
-			ADD_MACRO_ARG(msg->host->data);
-		}
-
-					
 		break;
 	}
 	case 'f': {
