@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afstreams.c,v 1.5 1999/11/15 12:30:42 bazsi Exp $
+ * $Id: afstreams.c,v 1.6 1999/11/16 17:30:05 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -115,7 +115,7 @@ static int do_stream_read(int fd, UINT32 *pri, UINT32 length, UINT8 *buf)
 static void stream_read_callback(struct nonblocking_fd *fd)
 {
 	CAST(stream_fd, self, fd);
-	char line[MAX_LINE];
+	char line[MAX_LINE*10];
 	UINT32 pri;
 	int n;
 	
@@ -135,10 +135,17 @@ static void stream_read_callback(struct nonblocking_fd *fd)
 
 		while (eol) {
 
-			length = eol - bol;			
-			li = make_log_info(length, bol);
-			li->pri = pri;
-			HANDLE_LOG(self->pipe, li);
+			while (*bol <= 26) {
+				bol++;
+				n--;
+			}
+			
+			length = eol - bol;
+			if (length) {
+				li = make_log_info(length, bol);
+				li->pri = pri;
+				HANDLE_LOG(self->pipe, li);
+			}
 
 			n -= length + 1;
 			bol = eol + 1;
@@ -236,9 +243,9 @@ static int do_init_afstreams_source(struct log_handler *c, struct syslog_conf *c
 		}
 #else
 		if (self->door_name) {
-		  close_fd(self->stream_fd);
-		  werror("sun-door support is not compiled in, door=%S\n", self->door_name);
-		  return ST_FAIL | ST_QUIT;
+			close_fd(self->stream_fd);
+			werror("sun-door support is not compiled in, door=%S\n", self->door_name);
+			return ST_FAIL | ST_QUIT;
 		}
 #endif
 	}
