@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: log.c,v 1.13 1999/08/29 17:37:56 bazsi Exp $
+ * $Id: log.c,v 1.14 1999/11/16 17:30:05 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -42,6 +42,7 @@ static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data)
 	char *src;
 	int left;
 	int pri;
+	time_t now = time(NULL);
 	
 	src = data;
 	left = length;
@@ -76,7 +77,6 @@ static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data)
 	if (left >= 15) {
 		if (src[3] == ' ' && src[6] == ' ' && src[9] == ':' && src[12] == ':') {
 			struct tm tm, *nowtm;
-			time_t now = time(NULL);
 
 			lm->date = c_format_cstring("%s", 15, src);
 			src += 15;
@@ -93,7 +93,7 @@ static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data)
 		}
 	}
 
-	{
+	if (lm->date) {
 		char *oldsrc;
 		int oldleft;
 		
@@ -128,6 +128,9 @@ static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data)
 		src = oldsrc;
 		left = oldleft;
 	}
+	else {
+		lm->stamp = now;
+	}
 
 	lm->msg = c_format_cstring("%s", left, src);
 }
