@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: syslog-names.c,v 1.4 1999/08/29 17:37:56 bazsi Exp $
+ * $Id: syslog-names.c,v 1.5 1999/10/26 18:16:25 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -37,8 +37,8 @@ struct sl_name sl_levels[] = {
 	{ "info", LOG_INFO },
 	{ "notice", LOG_NOTICE },
 	{ "panic", LOG_EMERG },             /* DEPRECATED */
-	{ "warn", LOG_WARNING },            /* DEPRECATED */
 	{ "warning", LOG_WARNING },
+	{ "warn", LOG_WARNING },            /* DEPRECATED */
 	{ NULL, -1}
 }; 
 
@@ -83,6 +83,18 @@ int syslog_lookup_name(const char *name, struct sl_name names[])
 	return -1;
 }
 
+int syslog_lookup_value(int value, struct sl_name names[])
+{
+	int i;
+
+	for (i = 0; names[i].name; i++) {
+		if (names[i].value == value) {
+			return i;
+		}
+	}
+	return -1;
+}
+
 UINT32 syslog_make_range(UINT32 r1, UINT32 r2)
 {
 	UINT32 x;
